@@ -23,11 +23,13 @@ GraphBitMap=""
 GraphBitMapLen=0
 GraphBitMapHeight=0
 
+StatisticsBitMap=""
+StatisticsBitMapLen=110
+StatisticsBitMapHeight=65
+
 DisplayIsOn=True
 ScrollToEnd=False
 
-arrStatData=[[0]*3,  [0]*3,  [0]*3,  [0]*3] # Accumulated time/phase, Amount of times/phase, Max time/phase
-
 
 #init values
 Sampling_interval=1000 #in milliseconds
@@ -108,4 +110,16 @@ arrLogFiles=[]
 arrLogFilesIndex=0
 LogFileSelectedDate=""
 
-#LastIndex=-1
+#Colors
+State1Color="#009100"
+State2Color="#005000"
+State3Color="#97320e"
+State4Color="#6D0000"
+MovementBarColor="Yellow"
+AlarmColor="Red"
+AlarmTimeWindowColor="Orange"
+GraphBackground="#101010"
+
+
+
+
