@@ -47,7 +47,7 @@ def SetAlarm():
         event = alarm.get_event(data.AlarmID) #read out again to check if set correctly
         print "* Alarm will go off on:",  time.ctime(event.trigger)
     else:
-        print "* Can not set alarm, Maemo interface not available"
+        print "* Will not set alarm, Maemo interface not available"
         data.AlarmID=1
         
     data.AlarmIsActive=False
@@ -72,7 +72,7 @@ def DeleteAlarm():
             except:
                 pass            
         else:
-            print "* Can not delete alarm, Maemo interface not available"
+            print "* Will not delete alarm, Maemo interface not available"
         
         data.AlarmID=-1
         
