@@ -173,8 +173,9 @@ def EditUserName():
 def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothing)
     r=GetSensorData()     
     if(r==1): #new data got added to array
-        ProcessData(False)      
-        ProcessAlarm()
+        ProcessData(False)   
+        GenerateStatisticData()   
+        ProcessAlarm()        
         
         WriteIntoRecordFile()
         
@@ -182,7 +183,7 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
 #        data.GraphStart=max(GraphLen-779, 0)
         
         data.ScrollToEnd=True
-        GenerateGraph(RecordWindow)    
+        GenerateGraphBitmap(RecordWindow)    
     
         if(records.Index==records.MaxArrayDataLen-1): 
             print "Stopped, array is full"
@@ -251,7 +252,7 @@ def InitMeasurement():
     GetFirstEntry()
     WriteIntoRecordFile()
    
-    GenerateGraph(RecordWindow)
+    GenerateGraphBitmap(RecordWindow)
     RecordWindow.UpdateScreen()
     
     RecordWindow.ui.CanvasWidget.show()
@@ -578,7 +579,7 @@ class frmRecordWindow(QMainWindow):
 #        scroller = self.ui.ScrollArea.property("kineticScroller").toPyObject()
 #        scroller.setEnabled(True)
         
-        self.Canvas = MyCanvas(self.ui.CanvasWidget)
+        self.Canvas = MyGraphCanvas(self.ui.CanvasWidget)
         
         self.ui.CanvasWidget.setMinimumSize(QtCore.QSize(1000, data.GraphBitMapHeight)) #needed?
         
@@ -684,13 +685,13 @@ class frmRecordWindow(QMainWindow):
 
     def ZoomIn(self):
         Zoom(+1)
-        GenerateGraph(self)
+        GenerateGraphBitmap(self)
         
 
 
     def ZoomOut(self):
         Zoom(-1)
-        GenerateGraph(self)
+        GenerateGraphBitmap(self)
 
 
 
@@ -700,7 +701,7 @@ class frmRecordWindow(QMainWindow):
         if(data.Trigger==data.maxTrigger): self.ui.bRaiseTrigger.setEnabled(False)
         else: self.ui.bRaiseTrigger.setEnabled(True)
          
-        GenerateGraph(self)
+        GenerateGraphBitmap(self)
         
         
         
@@ -710,7 +711,7 @@ class frmRecordWindow(QMainWindow):
         if(data.Trigger==0): self.ui.bLowerTrigger.setEnabled(False)
         else: self.ui.bLowerTrigger.setEnabled(True)
          
-        GenerateGraph(self)
+        GenerateGraphBitmap(self)
 
 
 
@@ -773,7 +774,8 @@ class frmViewWindow(QMainWindow):
 #        scroller = self.ui.ScrollArea.property("kineticScroller").toPyObject()
 #        scroller.setEnabled(True)
         
-        self.Canvas = MyCanvas(self.ui.CanvasWidget)
+        self.Canvas = MyGraphCanvas(self.ui.CanvasWidget)
+        self.StatisticsCanvas = MyStatCanvas(self)
         
         self.ui.CanvasWidget.setMinimumSize(QtCore.QSize(1000, data.GraphBitMapHeight)) #needed?
         
@@ -791,8 +793,10 @@ class frmViewWindow(QMainWindow):
         QtCore.QObject.connect(self.ui.bEditNote, QtCore.SIGNAL("clicked()"), self.EditNote)
 #        QtCore.QObject.connect(self.ui.bLeft, QtCore.SIGNAL("clicked()"), self.goLeft)
 #        QtCore.QObject.connect(self.ui.bRight, QtCore.SIGNAL("clicked()"), self.goRight)
+
         QtCore.QObject.connect(self.ui.actionAbout, QtCore.SIGNAL("triggered()"), self.About)
         QtCore.QObject.connect(self.ui.actionShowRecordData, QtCore.SIGNAL("triggered()"), self.ShowRecordData)
+        QtCore.QObject.connect(self.ui.actionExport, QtCore.SIGNAL("triggered()"), self.Export)
 
         
         #Add styles to buttons
@@ -838,20 +842,21 @@ class frmViewWindow(QMainWindow):
 
 #        d0=strftime("%a. %d.%m.%Y  %H:%M:%S", records.StartTime_tuple)
         d0=strftime("%a. %x %X", records.StartTime_tuple)
-        EndTime_tuple=Seconds2Tuple(Tuple2Seconds(records.StartTime_tuple)+records.Index*records.Sampling_interval*records.Value_smoothing/1000)
-        if(strftime("%d.%m.%Y", records.StartTime_tuple)==strftime("%d.%m.%Y", EndTime_tuple)):
-#            d1=strftime("%H:%M:%S", EndTime_tuple) #on same day, only show date once
+#        EndTime_tuple=Seconds2Tuple(Tuple2Seconds(records.StartTime_tuple)+records.Index*records.Sampling_interval*records.Value_smoothing/1000)
+        if(strftime("%d.%m.%Y", records.StartTime_tuple)==strftime("%d.%m.%Y", records.EndTime_tuple)):
+#            d1=strftime("%H:%M:%S", records.EndTime_tuple) #on same day, only show date once
 #        else:
 #            d1=strftime("%a. %d.%m.%Y  %H:%M:%S", EndTime_tuple) 
-            d1=strftime("%X", EndTime_tuple) #on same day, only show date once
+            d1=strftime("%X", records.EndTime_tuple) #on same day, only show date once
         else:
-            d1=strftime("%a. %x %X", EndTime_tuple) 
+            d1=strftime("%a. %x %X", records.EndTime_tuple) 
 #            
 #        diff_sec=records.Index*records.Sampling_interval*records.Value_smoothing/1000
-        diff_sec=Tuple2Seconds(EndTime_tuple)-Tuple2Seconds(records.StartTime_tuple)
-#        print diff_sec,  Tuple2Seconds(EndTime_tuple), Tuple2Seconds(records.StartTime_tuple)
+#        diff_sec=Tuple2Seconds(records.EndTime_tuple)-Tuple2Seconds(records.StartTime_tuple)
+        diff_sec=records.EndTime_seconds-records.StartTime_seconds
+#        print diff_sec,  Tuple2Seconds(records.EndTime_tuple), Tuple2Seconds(records.StartTime_tuple)
 #        diff_tuple=Seconds2Tuple(diff_sec)
-#        print diff_tuple,  records.StartTime_tuple,  EndTime_tuple
+#        print diff_tuple,  records.StartTime_tuple,  records.EndTime_tuple
 #        diff=strftime("%H:%M:%S", diff_tuple)
 #        diff=time.strftime("%X", time.gmtime(diff_sec))
         diff=time.strftime("%H:%M:%S", time.gmtime(diff_sec))
@@ -908,8 +913,9 @@ class frmViewWindow(QMainWindow):
 #            QtGui.QMessageBox.warning(self, 'File empty!', "The data in the record file\n"+data.logfilename+"\ncontains no data!", QtGui.QMessageBox.Ok)
         elif(r==9): #Record too old
             QtGui.QMessageBox.warning(self, 'File version too old!', "Can not load record \n"+data.logfilename+"\nas it got created from SleepAnalyser version <1.6 and is not compatible with the current SleepAnalyser version.", QtGui.QMessageBox.Ok)
-        LoadFileList()
+#        LoadFileList()
         ProcessData(True)
+        GenerateStatisticData()
         data.Xscale=1 #default zoom level
 #        data.Xscale=0
 #        data.GraphStart=max(records.LastIndex-data.arrXscale[data.Xscale]*775, 0)
@@ -917,7 +923,10 @@ class frmViewWindow(QMainWindow):
 #        data.ChangesInGraph=True #Make sure it only gets refreshed once
 
 
-        GenerateGraph(self)
+        GenerateGraphBitmap(self)
+        GenerateStatisticsBitmap(self)
+        
+        self.update() #update statistic bars
       
         
         
@@ -933,7 +942,6 @@ class frmViewWindow(QMainWindow):
     ## 
     ###########################################################################
     def NextLogFile(self):
-        
         data.arrLogFileIndex=(data.arrLogFileIndex+1)  % len(data.arrLogFiles)
         data.logfilename=data.arrLogFiles[data.arrLogFileIndex]
         self.ShowLogFile()
@@ -963,7 +971,7 @@ class frmViewWindow(QMainWindow):
 #        data.ChangesInGraph=True #Make sure it only gets refreshed once
         
         
-        GenerateGraph(self)
+        GenerateGraphBitmap(self)
         
         
         
@@ -987,7 +995,7 @@ class frmViewWindow(QMainWindow):
 #        data.ChangesInGraph=True #Make sure it only gets refreshed once
         
         
-        GenerateGraph(self)
+        GenerateGraphBitmap(self)
 
         
     ###########################################################################
@@ -996,7 +1004,11 @@ class frmViewWindow(QMainWindow):
     def RaiseTrigger(self):   
         MoveTrigger(+1)
         
-        GenerateGraph(self)
+        GenerateGraphBitmap(self)
+        
+        GenerateStatisticData()
+        GenerateStatisticsBitmap(self)
+        self.update() #update statistic bars
 
 
     ###########################################################################
@@ -1005,7 +1017,11 @@ class frmViewWindow(QMainWindow):
     def LowerTrigger(self):     
         MoveTrigger(-1)
         
-        GenerateGraph(self)
+        GenerateGraphBitmap(self)
+        
+        GenerateStatisticData()
+        GenerateStatisticsBitmap(self)
+        self.update() #update statistic bars
     
         
 #    ###########################################################################
@@ -1082,6 +1098,7 @@ class frmViewWindow(QMainWindow):
         data.logfilename=tmp2[l-1]
         data.logfolder=string.replace(tmp,  data.logfilename,  "") #get folder of selected file
         print "Set folder=",  data.logfolder,  ", file=",  data.logfilename
+        LoadFileList()
         self.ShowLogFile()
     
     
@@ -1091,7 +1108,7 @@ class frmViewWindow(QMainWindow):
     def ShowFileDialog(self):        
         data.logfolder=string.replace(data.logfolder, "~",  data.homedir) #workaround
         if(data.debug==1): print "Open file dialog in:",  data.logfolder
-        tmp= QFileDialog.getOpenFileName(None,"Open SleepAnalyser Log File", data.logfolder, "Log Files (*.csv)");
+        tmp= QFileDialog.getOpenFileName(None,"Open SleepAnalyser Log File", data.logfolder, "Log Files (*.csv)")
         print "Selected file:",  tmp
         return tmp
         
@@ -1141,7 +1158,14 @@ class frmViewWindow(QMainWindow):
         AdditionalInfoWindow.show()
 
 
-
+    def Export(self):
+        filename=string.replace(data.logfilename, ".csv",  "")
+        tmp=QFileDialog.getSaveFileName(None,"Export graph as", data.defaultlogfolder+filename, "PNG-Image (*.png)") #;;JPEG-Image (*.jpg)
+        if(tmp!=""):
+            print "Export graph as :",  tmp
+            r=data.GraphBitMap.save(tmp,  "png",  -1)
+            if(r==True): print "Export was successful"
+            else: QtGui.QMessageBox.warning(self, 'Could not export file', "Failed to save graph as file\n"+tmp, QtGui.QMessageBox.Ok)
 
 
 
@@ -1357,12 +1381,12 @@ class frmAdditionalInfoWindow(QMainWindow):
         shortfolder=string.replace(shortfolder, "//", "/") #workaround
         
         d0=strftime("%a. %d.%m.%Y  %H:%M:%S", records.StartTime_tuple)
-        EndTime_seconds=Tuple2Seconds(records.StartTime_tuple)+records.Index*records.Sampling_interval*records.Value_smoothing/1000
-        EndTime_tuple=Seconds2Tuple(EndTime_seconds)
-        if(strftime("%d.%m.%Y", records.StartTime_tuple)==strftime("%d.%m.%Y", EndTime_tuple)):
-            d1=strftime("%H:%M:%S", EndTime_tuple) #on same day, only show date once
+#        EndTime_seconds=Tuple2Seconds(records.StartTime_tuple)+records.Index*records.Sampling_interval*records.Value_smoothing/1000
+#        EndTime_tuple=Seconds2Tuple(records.EndTime_seconds)
+        if(strftime("%d.%m.%Y", records.StartTime_tuple)==strftime("%d.%m.%Y", records.EndTime_tuple)):
+            d1=strftime("%H:%M:%S", records.EndTime_tuple) #on same day, only show date once
         else:
-            d1=strftime("%a. %d.%m.%Y  %H:%M:%S", EndTime_tuple) 
+            d1=strftime("%a. %d.%m.%Y  %H:%M:%S", records.EndTime_tuple) 
         
         diff_sec=records.Index*records.Sampling_interval*records.Value_smoothing/1000
 #        diff=time.strftime("%X", time.gmtime(diff_sec))
@@ -1378,7 +1402,7 @@ class frmAdditionalInfoWindow(QMainWindow):
                 a1=strftime("%a. %d.%m.%Y  %H:%M:%S", records.AlarmTimeWindowEnd_tuple) 
             alarm="<b>Alarm Time Window:</b> "+a0+" - "+a1 + "<br>"
             if(records.AlarmTime_seconds!=-1): #alarm was set
-                if(EndTime_seconds>=records.AlarmTime_seconds): #alarm got set off during recording
+                if(records.EndTime_seconds>=records.AlarmTime_seconds): #alarm got set off during recording
                     alarm=alarm+"<b>Alarm:</b> Alarm went off on: "+strftime("%a. %d.%m.%Y  %H:%M:%S", records.AlarmTime_tuple)+"<br>"
                     if(records.AlarmTimeWindowEnd_seconds<=records.AlarmTime_seconds):
                         alarm=alarm+"<b>Alarm reason:</b> End of alarm time window<br>"
@@ -1400,12 +1424,31 @@ class frmAdditionalInfoWindow(QMainWindow):
         "<b>Note:</b> "+records.Note+"<br>" +\
         alarm +\
         "<b>Trigger level:</b> "+str(records.Trigger) + "<br>" + \
-        "<b>Condition of record:</b> "+str(records.status)+"<br><br>" + \
-        "<b>Sampling interval:</b> "+str(records.Sampling_interval) + " ms<br>" + \
+        "<b>Condition of record:</b> "+str(records.status)+"<br><br>"
+        
+            
+#        t_total=(records.EndTime_seconds-records.StartTime_seconds)
+#        print records.EndTime_seconds,  records.StartTime_seconds,  t_total
+#        if(t_total==0):  t_total=1 #division by zerro prevention
+#        pa=records.arrStatData[0][0]*100/t_total
+#        pb=records.arrStatData[1][0]*100/t_total
+#        pc=records.arrStatData[2][0]*100/t_total
+##        pd=records.arrStatData[3][0]*100/t_total
+#        pl=100-pa-pb-pc
+         
+        txt=txt+"<b>Statistics:</b><table>\n" + \
+                "<tr><td><b>Sleep phase: </b></td>   <td><b>Total time: </b></td>                                     <td><b>Longest time:</b></td>                                    <td><b>Count: </b></td>                     <td colspan=2><b>Time percent:</b></td>\n" + \
+                "<tr><td><b>Awake:</b></td>         <td>"+strftime("%X", time.gmtime(records.arrStatData[3][0]))+"</td>    <td>-</td>    <td>-</td>    <td>"+str(records.arrStatData[3][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State4.png"+"\" width="+str(records.arrStatData[3][3]*2)+" height=25</td></tr>\n" + \
+                "<tr><td><b>Light:</b></td>         <td>"+strftime("%X", time.gmtime(records.arrStatData[2][0]))+"</td>    <td>"+strftime("%X", time.gmtime(records.arrStatData[2][2]))+"</td>    <td>"+str(records.arrStatData[2][1])+"</td>    <td>"+str(records.arrStatData[2][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State3.png"+"\" width="+str(records.arrStatData[2][3]*2)+" height=25</td></tr>\n" + \
+                "<tr><td><b>Middle:</b></td>        <td>"+strftime("%X", time.gmtime(records.arrStatData[1][0]))+"</td>    <td>"+strftime("%X", time.gmtime(records.arrStatData[1][2]))+"</td>    <td>"+str(records.arrStatData[1][1])+"</td>    <td>"+str(records.arrStatData[1][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State2.png"+"\" width="+str(records.arrStatData[1][3]*2)+" height=25</td></tr>\n" + \
+                "<tr><td><b>Deep:</b></td>          <td>"+strftime("%X", time.gmtime(records.arrStatData[0][0]))+"</td>    <td>"+strftime("%X", time.gmtime(records.arrStatData[0][2]))+"</td>    <td>"+str(records.arrStatData[0][1])+"</td>    <td>"+str(records.arrStatData[0][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State1.png"+"\" width="+str(records.arrStatData[0][3]*2)+" height=25</td></tr>\n" + \
+              "</table><br><br>\n"
+        
+        txt=txt+"<b>Sampling interval:</b> "+str(records.Sampling_interval) + " ms<br>" + \
         "<b>Sampling smoothing:</b> "+str(records.Sample_smoothing) + "<br>" + \
         "<b>Value smoothing:</b> "+str(records.Value_smoothing)
 
-        self.ui.textBrowser.setHtml(txt)
+        self.ui.textBrowser.setHtml("<html><body>"+txt+"</html></body>")
 
 
     ###########################################################################
@@ -1678,7 +1721,7 @@ class DisplayStatusDaemon:
 ###########################################################################
 ## 
 ###########################################################################
-class MyCanvas(QtGui.QWidget):
+class MyGraphCanvas(QtGui.QWidget):
     def __init__(self, parent):
         QMainWindow.__init__(self, parent)    
         self.setGeometry(0, 0, 770, data.GraphBitMapHeight)
@@ -1691,10 +1734,10 @@ class MyCanvas(QtGui.QWidget):
     ###########################################################################
     def paintEvent(self, event):
         if(data.DisplayIsOn==False):
-            if(data.debug==1): print "-> o Do not paint event, Display is off!"
+            if(data.debug==1): print "-> o Do not paint event (Graph), Display is off!"
             return
         else:
-            if(data.debug==1): print "-> x paint event"
+            if(data.debug==1): print "-> x paint event (Graph)"
 
         
         if(data.ScrollToEnd==True): 
@@ -1705,10 +1748,8 @@ class MyCanvas(QtGui.QWidget):
 #        DrawGraph(self,  QtGui)
 
         paint = QtGui.QPainter()
-        paint.begin(self)
-        
+        paint.begin(self)        
         paint.drawPixmap(0, 0, data.GraphBitMap) #load graph from Bitmap
-
         paint.end()
 
     
@@ -1717,17 +1758,48 @@ class MyCanvas(QtGui.QWidget):
     
     
     
+###########################################################################
+## 
+###########################################################################
+class MyStatCanvas(QtGui.QWidget):
+    def __init__(self, parent):
+        QMainWindow.__init__(self, parent)    
+        self.setGeometry(402, 280, data.StatisticsBitMapLen,  data.StatisticsBitMapHeight)
+        
+
+    ###########################################################################
+    ## 
+    ###########################################################################
+    def paintEvent(self, event):
+        if(data.DisplayIsOn==False):
+            if(data.debug==1): print "-> o Do not paint event (Statistics), Display is off!"
+            return
+        else:
+            if(data.debug==1): print "-> x paint event (Statistics)"
+
+        paint = QtGui.QPainter()
+        paint.begin(self)        
+        paint.drawPixmap(0, 0, data.StatisticsBitMap) #load statistics from Bitmap
+        paint.end()
+
+    
+    
+    
+    
+    
+    
+    
     
     
 ###########################################################################
 ## 
 ###########################################################################        
-def GenerateGraph(self):    
+def GenerateGraphBitmap(self):    
     if(data.DisplayIsOn==False):
-        if(data.debug==1): print "-> o Do not Generate Graph, Display is off!"
+        if(data.debug==1): print "-> o Do not Generate Graph Bitmap, Display is off!"
         return
     else:
-        if(data.debug==1): print "-> x Generate Graph"
+        if(data.debug==1): print "-> x Generate Graph Bitmap"
 
     Xscale=data.arrXscale[data.Xscale]
 #        data.GraphBitMapLen=max((records.LastIndex+5)/Xscale + 2 ,  770)
@@ -1735,10 +1807,11 @@ def GenerateGraph(self):
     data.GraphBitMapHeight=data.Ysize+34
     
 #    print "GraphBitMapLen:",  data.GraphBitMapLen,  ", GraphBitMapHeight:",  data.GraphBitMapHeight ,  ", Ysize is:", data.Ysize  
-    
-    data.GraphBitMap = QtGui.QPixmap(data.GraphBitMapLen, data.GraphBitMapHeight) #create bitmap for graph
-    
-    DrawGraph(data.GraphBitMap,  QtGui) # draw graph
+    try:
+        data.GraphBitMap = QtGui.QPixmap(data.GraphBitMapLen, data.GraphBitMapHeight) #create bitmap for graph    
+        DrawGraph(data.GraphBitMap,  QtGui) # draw graph
+    except:
+        print "Error while creating the graph"
     
 #    ViewWindowCanvas.setGeometry(0, 0, data.GraphBitMapLen, data.GraphBitMapHeight)  #set size of canvas to graph 
     self.Canvas.setGeometry(0, 0, data.GraphBitMapLen, data.GraphBitMapHeight)  #set size of canvas to graph 
@@ -1756,5 +1829,28 @@ def GenerateGraph(self):
     
     
     
+    
+###########################################################################
+## 
+###########################################################################        
+def GenerateStatisticsBitmap(self):    
+    if(data.DisplayIsOn==False):
+        if(data.debug==1): print "-> o Do not Generate Statistics Bitmap, Display is off!"
+        return
+    else:
+        if(data.debug==1): print "-> x Generate Statistics Bitmap"
+
+    try:
+        data.StatisticsBitMap = QtGui.QPixmap(data.StatisticsBitMapLen,  data.StatisticsBitMapHeight) #create bitmap for graph   
+        DrawStatistic(data.StatisticsBitMap,  QtGui) #draw statistics
+    except:
+        print "Error while creating the graph"
+    
+    
+#    self.ui.CanvasWidget.hide()
+#    self.ui.CanvasWidget.show()
+    
+    
+    
 ###########################################################################
 main() # Now we can start it.
