@@ -4,15 +4,42 @@
 
 MaxArrayDataLen=8640 #(1 value/10sec for 24h), 6*24*60
 
-#             [0]=time            [1]=X,                [2]=Y,                [3]=X+Y Derivation, [4]=Time since last movement over treshhold, [5]=event
 arrData=[[0]*MaxArrayDataLen, [0]*MaxArrayDataLen, [0]*MaxArrayDataLen, [0]*MaxArrayDataLen,        [0]*MaxArrayDataLen ,             [0]*MaxArrayDataLen]  
+#field 1:
+    # samples
+#field 2:
+    # Time
+    # X movements
+    # Y movement
+    # Summ of X+Y Derivation
+    # Time since last movement over treshhold
+    # Event notes
+
 
 Index=-1
 LastIndex=-1 #maximum from Index and AlarmTimeWindowEnd index
 
+
+
+arrStatData=[[0]*4,  [0]*4,  [0]*4,  [0]*4] 
+#field 1:
+    # sleep state 1 (>30 min)
+    # sleep state 2 (>15 min)
+    # sleep state 3 (>7 min)
+    # sleep state 4 (<30 min)
+#field 2:
+    # Accumulated time/phase, Amount of times/phase, Max time/phase, time percent
+
+
+
+
+
 StartTime_tuple=-1
 StartTime_seconds=-1
 
+EndTime_tuple=-1
+EndTime_seconds=-1
+
 AlarmTime_tuple=-1
 AlarmTime_seconds=-1
 
